@@ -92,7 +92,39 @@ class AuthMethodOidc(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AuthMethodOidc.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                scope_id: builtins.str,
+                account_claim_maps: typing.Optional[typing.Sequence[builtins.str]] = None,
+                allowed_audiences: typing.Optional[typing.Sequence[builtins.str]] = None,
+                api_url_prefix: typing.Optional[builtins.str] = None,
+                callback_url: typing.Optional[builtins.str] = None,
+                claims_scopes: typing.Optional[typing.Sequence[builtins.str]] = None,
+                client_id: typing.Optional[builtins.str] = None,
+                client_secret: typing.Optional[builtins.str] = None,
+                client_secret_hmac: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                disable_discovered_config_validation: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                idp_ca_certs: typing.Optional[typing.Sequence[builtins.str]] = None,
+                is_primary_for_scope: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                issuer: typing.Optional[builtins.str] = None,
+                max_age: typing.Optional[jsii.Number] = None,
+                name: typing.Optional[builtins.str] = None,
+                signing_algorithms: typing.Optional[typing.Sequence[builtins.str]] = None,
+                state: typing.Optional[builtins.str] = None,
+                type: typing.Optional[builtins.str] = None,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = AuthMethodOidcConfig(
@@ -319,7 +351,9 @@ class AuthMethodOidc(
     @account_claim_maps.setter
     def account_claim_maps(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "account_claim_maps").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "accountClaimMaps", value)
 
@@ -331,7 +365,9 @@ class AuthMethodOidc(
     @allowed_audiences.setter
     def allowed_audiences(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "allowed_audiences").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowedAudiences", value)
 
@@ -343,7 +379,9 @@ class AuthMethodOidc(
     @api_url_prefix.setter
     def api_url_prefix(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "api_url_prefix").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiUrlPrefix", value)
 
@@ -355,7 +393,9 @@ class AuthMethodOidc(
     @callback_url.setter
     def callback_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "callback_url").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "callbackUrl", value)
 
@@ -367,7 +407,9 @@ class AuthMethodOidc(
     @claims_scopes.setter
     def claims_scopes(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "claims_scopes").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "claimsScopes", value)
 
@@ -379,7 +421,9 @@ class AuthMethodOidc(
     @client_id.setter
     def client_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "client_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientId", value)
 
@@ -391,7 +435,9 @@ class AuthMethodOidc(
     @client_secret.setter
     def client_secret(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "client_secret").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecret", value)
 
@@ -403,7 +449,9 @@ class AuthMethodOidc(
     @client_secret_hmac.setter
     def client_secret_hmac(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "client_secret_hmac").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecretHmac", value)
 
@@ -415,7 +463,9 @@ class AuthMethodOidc(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "description").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -432,7 +482,9 @@ class AuthMethodOidc(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "disable_discovered_config_validation").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "disableDiscoveredConfigValidation", value)
 
@@ -444,7 +496,9 @@ class AuthMethodOidc(
     @idp_ca_certs.setter
     def idp_ca_certs(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "idp_ca_certs").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "idpCaCerts", value)
 
@@ -459,7 +513,9 @@ class AuthMethodOidc(
         value: typing.Union[builtins.bool, cdktf.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "is_primary_for_scope").fset)
+            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrimaryForScope", value)
 
@@ -471,7 +527,9 @@ class AuthMethodOidc(
     @issuer.setter
     def issuer(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "issuer").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "issuer", value)
 
@@ -483,7 +541,9 @@ class AuthMethodOidc(
     @max_age.setter
     def max_age(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "max_age").fset)
+            def stub(value: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxAge", value)
 
@@ -495,7 +555,9 @@ class AuthMethodOidc(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -507,7 +569,9 @@ class AuthMethodOidc(
     @scope_id.setter
     def scope_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "scope_id").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scopeId", value)
 
@@ -519,7 +583,9 @@ class AuthMethodOidc(
     @signing_algorithms.setter
     def signing_algorithms(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "signing_algorithms").fset)
+            def stub(value: typing.List[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "signingAlgorithms", value)
 
@@ -531,7 +597,9 @@ class AuthMethodOidc(
     @state.setter
     def state(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "state").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "state", value)
 
@@ -543,7 +611,9 @@ class AuthMethodOidc(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AuthMethodOidc, "type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
@@ -642,7 +712,37 @@ class AuthMethodOidcConfig(cdktf.TerraformMetaArguments):
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(AuthMethodOidcConfig.__init__)
+            def stub(
+                *,
+                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+                count: typing.Optional[jsii.Number] = None,
+                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
+                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
+                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
+                provider: typing.Optional[cdktf.TerraformProvider] = None,
+                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+                scope_id: builtins.str,
+                account_claim_maps: typing.Optional[typing.Sequence[builtins.str]] = None,
+                allowed_audiences: typing.Optional[typing.Sequence[builtins.str]] = None,
+                api_url_prefix: typing.Optional[builtins.str] = None,
+                callback_url: typing.Optional[builtins.str] = None,
+                claims_scopes: typing.Optional[typing.Sequence[builtins.str]] = None,
+                client_id: typing.Optional[builtins.str] = None,
+                client_secret: typing.Optional[builtins.str] = None,
+                client_secret_hmac: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                disable_discovered_config_validation: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                idp_ca_certs: typing.Optional[typing.Sequence[builtins.str]] = None,
+                is_primary_for_scope: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                issuer: typing.Optional[builtins.str] = None,
+                max_age: typing.Optional[jsii.Number] = None,
+                name: typing.Optional[builtins.str] = None,
+                signing_algorithms: typing.Optional[typing.Sequence[builtins.str]] = None,
+                state: typing.Optional[builtins.str] = None,
+                type: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
