@@ -58,7 +58,22 @@ class BoundaryProvider(
         :param token: The Boundary token to use, as a string or path on disk containing just the string. If set, the token read here will be used in place of authenticating with the auth method specified in "auth_method_id", although the recovery KMS mechanism will still override this. Can also be set with the BOUNDARY_TOKEN environment variable. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary#token BoundaryProvider#token}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BoundaryProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                addr: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                auth_method_id: typing.Optional[builtins.str] = None,
+                password_auth_method_login_name: typing.Optional[builtins.str] = None,
+                password_auth_method_password: typing.Optional[builtins.str] = None,
+                plugin_execution_dir: typing.Optional[builtins.str] = None,
+                recovery_kms_hcl: typing.Optional[builtins.str] = None,
+                tls_insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                token: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = BoundaryProviderConfig(
@@ -171,7 +186,9 @@ class BoundaryProvider(
     @addr.setter
     def addr(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "addr").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "addr", value)
 
@@ -183,7 +200,9 @@ class BoundaryProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -195,7 +214,9 @@ class BoundaryProvider(
     @auth_method_id.setter
     def auth_method_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "auth_method_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authMethodId", value)
 
@@ -210,7 +231,9 @@ class BoundaryProvider(
         value: typing.Optional[builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "password_auth_method_login_name").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "passwordAuthMethodLoginName", value)
 
@@ -225,7 +248,9 @@ class BoundaryProvider(
         value: typing.Optional[builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "password_auth_method_password").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "passwordAuthMethodPassword", value)
 
@@ -237,7 +262,9 @@ class BoundaryProvider(
     @plugin_execution_dir.setter
     def plugin_execution_dir(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "plugin_execution_dir").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pluginExecutionDir", value)
 
@@ -249,7 +276,9 @@ class BoundaryProvider(
     @recovery_kms_hcl.setter
     def recovery_kms_hcl(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "recovery_kms_hcl").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "recoveryKmsHcl", value)
 
@@ -266,7 +295,11 @@ class BoundaryProvider(
         value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "tls_insecure").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tlsInsecure", value)
 
@@ -278,7 +311,9 @@ class BoundaryProvider(
     @token.setter
     def token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(BoundaryProvider, "token").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "token", value)
 
@@ -324,7 +359,20 @@ class BoundaryProviderConfig:
         :param token: The Boundary token to use, as a string or path on disk containing just the string. If set, the token read here will be used in place of authenticating with the auth method specified in "auth_method_id", although the recovery KMS mechanism will still override this. Can also be set with the BOUNDARY_TOKEN environment variable. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/boundary#token BoundaryProvider#token}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BoundaryProviderConfig.__init__)
+            def stub(
+                *,
+                addr: builtins.str,
+                alias: typing.Optional[builtins.str] = None,
+                auth_method_id: typing.Optional[builtins.str] = None,
+                password_auth_method_login_name: typing.Optional[builtins.str] = None,
+                password_auth_method_password: typing.Optional[builtins.str] = None,
+                plugin_execution_dir: typing.Optional[builtins.str] = None,
+                recovery_kms_hcl: typing.Optional[builtins.str] = None,
+                tls_insecure: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+                token: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument addr", value=addr, expected_type=type_hints["addr"])
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument auth_method_id", value=auth_method_id, expected_type=type_hints["auth_method_id"])
